ArrowSchemaProvider

Trait ArrowSchemaProvider 

pub trait ArrowSchemaProvider {
    // Required method
    fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema;

    // Provided method
    fn get_schema_map() -> HashMap<String, String> { ... }
}
Provides Apache Arrow schema definitions for data types.

Required Methods

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Returns the Arrow schema for this type with optional metadata.

Provided Methods

fn get_schema_map() -> HashMap<String, String>

Returns a map of field names to their Arrow data types.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl ArrowSchemaProvider for AccountState

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for Bar

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for BettingInstrument

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for BinaryOption

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for Cfd

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for Commodity

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for CryptoFuture

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for CryptoOption

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for CryptoPerpetual

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for CurrencyPair

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for Equity

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for ExecutionMassStatus

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for FillReport

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for FundingRateUpdate

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for FuturesContract

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for FuturesSpread

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for IndexInstrument

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for IndexPriceUpdate

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for InstrumentAny

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for InstrumentClose

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for InstrumentStatus

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for MarkPriceUpdate

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OptionContract

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OptionSpread

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderAccepted

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderBookDelta

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderBookDepth10

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderCancelRejected

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderCanceled

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderDenied

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderEmulated

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderExpired

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderFilled

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderInitialized

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderModifyRejected

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderPendingCancel

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderPendingUpdate

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderRejected

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderReleased

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderSnapshot

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderStatusReport

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderSubmitted

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderTriggered

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for OrderUpdated

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for PerpetualContract

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for PositionAdjusted

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for PositionChanged

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for PositionClosed

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for PositionOpened

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for PositionSnapshot

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for PositionStatusReport

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for QuoteTick

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for TokenizedAsset

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Source

impl ArrowSchemaProvider for TradeTick

Source

fn get_schema(metadata: Option<HashMap<String, String>>) -> Schema

Implementors